#!/usr/bin/env Rscript
source("predict_wrapper.R")

args = commandArgs(trailingOnly=TRUE)

# IMPORTANT CONSTANTS
Ncore = 8 # number of cores per job
Nrep = 8 # number of 10-fold CV repeats per job
Nbg = 8 # number of random background shuffles per job

ALLOWED_DATASOURCE = c("gt", "ccle")
ALLOWED_DATATYPE = c("mut", "rppa", "rnaseq", "rpparnaseq")
ALLOWED_TISSUE = c("kidney", "liver", "urinarytract", "stomach", "oesophagus", "endometrium", "upperaerodigestivetract", "largeintestine", "centralnervoussystem", "breast", "pancreas", "ovary", "skin", "haematopoieticandlymphoidtissue", "lung", "all")
ALLOWED_METHOD = c("pls", "lasso", "elasticnet", "regressiontree", "dummy", "plsmulti", "maxcor")
ALLOWED_INTEGRATION = c("early", "late")
ALLOWED_SEN = c("gt", "ccle", "ctrp")

postfix=""

print(args)

if(length(args)==10) {
  
  datasource = args[1]
  datatype = args[2]
  version = args[3]
  tissue = args[4]
  sen = args[5]
  method = args[6]
  matched = as.logical(args[7])
  remove_dups = as.logical(args[8])
  integration = args[9]
  num = as.numeric(args[10])
  
  if(!(datasource %in% ALLOWED_DATASOURCE)) {
    print("Unknown datasource, quitting.")
    return()
  }
  if(!(datatype %in% ALLOWED_DATATYPE)) {
    print("Unknown datasource, quitting.")
    return()
  }
  if(!(tissue %in% ALLOWED_TISSUE)) {
    print("Unknown tissue, quitting.")
    return()
  }
  if(!(sen %in% ALLOWED_SEN)) {
    print("Unknown tissue, quitting.")
    return()
  }
  if(!(method %in% ALLOWED_METHOD)) {
    print("Unknown learning method, quitting.")
    return()
  }
  if(is.na(matched)) {
    print("matched parameter needs to be logical, quitting.")
    return()
  }
  if(is.na(remove_dups)) {
    print("remove_dups parameter needs to be logical, quitting.")
    return()
  }
  if(!(integration %in% ALLOWED_INTEGRATION)) {
    print("Unknown integration method, quitting.")
    return()
  }
  if(is.na(num)) {
    print("Run number needs to be numeric, quitting.")
    return()
  }
} else {
  print("Wrong number of arguments")
  return()
}

# DATAX
if(datatype=="mut") {
  filt_settings = NULL
  dataX = list(datasource=datasource, datatype=datatype, tissue=tissue)
  match_CLs = list(list(datasource=datasource, datatype="rppa", tissue=tissue),
                   list(datasource=datasource, datatype="rnaseq", tissue=tissue))
}
if(datatype=="rppa") {
  filt_settings = list(mean_filt=-999, sd_filt=0.1)  # default (not always applicable)
  dataX = list(datasource=datasource, datatype=datatype, tissue=tissue)
  match_CLs = list(list(datasource=datasource, datatype="mut", tissue=tissue),
                   list(datasource=datasource, datatype="rnaseq", tissue=tissue))
} else if(datatype=="rnaseq") {
  filt_settings = list(mean_filt=2.0, sd_filt=0.5) # default (not always applicable)
  dataX = list(datasource=datasource, datatype=datatype, tissue=tissue)
  match_CLs = list(list(datasource=datasource, datatype="mut", tissue=tissue),
                   list(datasource=datasource, datatype="rppa", tissue=tissue))
} else if(datatype=="rpparnaseq") {
  dataX = list(list(datasource=datasource, datatype="rppa", tissue=tissue),
               list(datasource=datasource, datatype="rnaseq", tissue=tissue))
  filt_settings = list(list(mean_filt=-999, sd_filt=0.1), list(mean_filt=2.0, sd_filt=0.5))
  match_CLs = list(datasource=datasource, datatype="mut", tissue=tissue)
}

# no mutation data for gt-endometrium
if(datasource=="gt" & tissue=="endometrium" & matched) {
  match_CLs = list(list(datasource=datasource, datatype="rppa", tissue=tissue),
                   list(datasource=datasource, datatype="rnaseq", tissue=tissue))
}

if(!matched)
  match_CLs = NULL

if(version!="-" & typeof(dataX[[1]])!="list")
  dataX[['version']]=version


dataY = list(datasource=sen, datatype="sen", tissue=tissue)

out = predict_wrapper(dataX=dataX, 
                 dataY=dataY, 
                 method=method, 
                 match_CLs=match_CLs,
                 remove_dups=remove_dups, 
                 filt_settings=filt_settings, 
                 Nrep=Nrep, 
                 Nbg=Nbg, 
                 Ncore=Ncore,
                 integration=integration)


filename = paste("analysis/out_", datasource,"_",datatype,"_version",version,"_", tissue,"_sen",sen,"_",method,"_matched",matched,"_removeDups",remove_dups,"_integration",integration,"_",num,".RData", sep="")

save(out, file = filename)

a=1
b=2
c=a+b

